package extensions.awt;
import java.awt.*;
import java.util.*;
import java.io.*;
import extensions.lang.*;
import extensions.io.*;

class JideClassPathDialogHandler extends Action
{
  public void run()
    { (new ClassPathDialog((Frame)forward)).show(); }
}

class JideHomePathDialogHandler extends Action
{
  public void run()
  {
    Jide j = (Jide) forward;
    PromptDialog pd = new
      PromptDialog(j,"HOMEPATH (i.e. java.home)",System.getProperty("java.home"),20);
    pd.response = j.homePath;
    pd.show();
    if (pd.okClicked())
      j.homePath = pd.response;
  }
}

class JideCompileAdapter extends Action
{ public void run() { ((Jide)forward).compile(false); } }

class JideMakeAdapter extends Action
{ public void run() { ((Jide)forward).compile(true); } }

class JideRunAppAdapter extends Action
{ public void run() { ((Jide)forward).runApp(); } }

class JideRunAppletAdapter extends Action
{ public void run() { ((Jide)forward).runApplet(); } }

class JideThreadsHandler implements ActionProtocol
{
  public final void action
    (Component forward, Event evt, Object what)
    { new ThreadFrame(); }
}

class JideAboutHandler implements ActionProtocol
{
  public final void action
    (Component forward, Event evt, Object what)
  {
    MessageDialog.notifyUser(forward,
      "Percolate your Java with Jide",
      "Java IDE 1.0.2.03\n"
      + "100% Pure Java JDK 1.0.2\n"
      + "jsmall@laser.net");
  }
}

public class Jide extends Jedit
{
  protected static String homePath;

  static
  {
    homePath = System.getProperty("java.home");
  }

  private MenuItemAction compileMI, makeMI, runMI, runAppletMI;

  private void menuEnables(int event)
  {
    if (compileMI == null)
      return;
    compileMI.disable();
    makeMI.disable();
    runMI.disable();
    runAppletMI.disable();
    switch (event)  {
      case FileTextArea.NEW_FILE:
        setTitle("Untitled.java");
        compileMI.enable();
        makeMI.enable();
        break;
      case FileTextArea.BROWSE:
      case FileTextArea.OPEN:
      case FileTextArea.SAVE:
        if (getFile().getName().lastIndexOf(".java") > 0)  {
           compileMI.enable();
           makeMI.enable();
           runMI.enable();
        }
        else if (getFile().getName().lastIndexOf(".html") > 0)
          runAppletMI.enable();
        break;
    }
  }

  /** Implements a universal observer interface. */
  public boolean update(Object anySubject, Object what)
  {
    if (anySubject instanceof FileTextArea)
      menuEnables(((FileTextArea)anySubject).event);
    return super.update(anySubject,what);
  }

  private void init()
  {
    MenuBar mb = getMenuBar();
    Menu m = new Menu("Java");
    m.add(new MenuItemAction("CLASSPATH ...",new JideClassPathDialogHandler()));
    m.add(new MenuItemAction("HOMEPATH ...",new JideHomePathDialogHandler()));
    m.addSeparator();
    m.add(compileMI=new MenuItemAction("Compile",new JideCompileAdapter()));
    m.add(makeMI=new MenuItemAction("Make",new JideMakeAdapter()));
    m.add(runMI=new MenuItemAction("Run",new JideRunAppAdapter()));
    m.add(runAppletMI=new MenuItemAction("Run Applet",new JideRunAppletAdapter()));
    m.addSeparator();
    m.add(new MenuItemAction("System properties",SystemProperties.viewAdapter()));
    m.add(new MenuItemAction("Threads",new JideThreadsHandler()));
    mb.add(m);
    m = new Menu("Help");
    m.add(new MenuItemAction("About",new JideAboutHandler()));
    mb.setHelpMenu(m);
    menuEnables(getEvent());
    setTitle(getFile().getName());
  }

  public Jide()
    { init(); }

  public Jide(Jide j)
  {
    super((Jedit)j);
    init();
  }

  public Jide(File f, boolean readOnly, boolean promptUser)
  {
    super(f,readOnly,promptUser);
    init();
  }

  /** Clone this Jide along with its contents.
    * The cloned Jide is in browse (read only) mode
    */
  public Object clone()
    { return new Jide(this); }

  /** Spawn a new Jide. */
  public Object spawn(File f, boolean readOnly, boolean promptUser)
  {
    if (f == null)
      return new Jide();
    return new Jide(f,readOnly,promptUser);
  }

  ProcessFrame compile(boolean make)
  {
    if (!saveAll(true))
      return null;
    if (getText() == null || getText().length() == 0)  {
      new MessageDialog(this,"Compile","Nothing to compile!");
      return null;
    }
    frameStack.push(this);
    ProcessFrame p = new ProcessFrame
      ("javac "+getFile().getName(),
        homePath + "/bin/javac "
        + (make? " -verbose -depend" : "")
        + " -classpath " + ClassPathDialog.classPath
        + " " + getFile().getAbsolutePath());
    try  {
      p.waitFor();
      p.toFront();
      TextArea ta = p.output;
      if (ta.getText() == null || ta.getText().length() == 0)  {
        ta.appendText("Successful compilation!");
        return p;
      }
    } catch (Throwable t)  {
      new DialogExtended(this,t,true);
    }
    return null;
  }

  private String className(StringTokenizer st)
  {
    while (st.hasMoreTokens())
      if (st.nextToken().equals("public") && st.hasMoreTokens())  {
        String className = st.nextToken();
        if (className.equals("final"))
          if (st.hasMoreTokens())
            className = st.nextToken();
          else
            return null;
        if (className.equals("class") && st.hasMoreTokens())
          return st.nextToken();
      }
    return null;
  }

  private String packageClassName()
  {
    StringTokenizer st = new StringTokenizer(getText()," \t\n;");
    while (st.hasMoreTokens())
      if (st.nextToken().equals("package"))
        if (st.hasMoreTokens())  {
          String packageName = st.nextToken();
          String cn = className(st);
          if (cn != null && cn.length() > 0)
            return packageName + "." + cn;
          else
            return null;
        }
        else
          return null;
    return className(new StringTokenizer(getText()," \t\n;"));
  }

  boolean recompile()
  {
    if (dirty())
      return true;
    String cpath = getFile().getAbsolutePath();
    try  {
      cpath = cpath.substring(0,cpath.lastIndexOf(".java"))+".class";
    } catch (Throwable t) { new DialogExtended(this,t); }
    return (getFile().lastModified() >
      (new File(cpath)).lastModified());
  }

  void runApp()
  {
    if (recompile())  {
      ProcessFrame p = compile(false);
      if (p == null)
        return;
      p.destroy();
    }
    PromptDialog pd = new PromptDialog
        (this,"Run package.className [arg,...]",50);
    pd.response = packageClassName();
    pd.show();
    if (pd.response != null && pd.okClicked()) {
      StringTokenizer st = new StringTokenizer(pd.response," \t");
      if (st.hasMoreTokens())
        pd.response = st.nextToken();
      if (pd.response.length() > 0)  {
        ProcessFrame p = new ProcessFrame
          ("java "+pd.response,
          homePath + "/bin/java "
          + " -classpath " + ClassPathDialog.classPath
          + File.pathSeparator + getFile().getAbsoluteParent()
          + " " + pd.response);
        try  {
          p.waitFor();
        } catch (Throwable t)  {
          new DialogExtended(this,t,true);
        } finally  {
          if (p.isOutput() || p.isError())
            p.toFront();
          else {
            p.destroy();
            toFront();
          }
        }
      }
    }
  }

  void runApplet()
  {
    if (dirty())
      if (!save(this,true))
        return;
    FileExtended fe = getFile();
    fe = fe.fileDialog(this,"Verify HTML Source",FileDialog.LOAD);
    if (fe == null)
      return;
    ProcessFrame pf = new ProcessFrame
      ("appletviewer "+fe.getName(),
      homePath + "/bin/appletviewer "
      + fe.getName());
    try  { pf.waitFor(); }
    catch (Throwable t) {}
    finally { pf.destroy(); }
    toFront();
  }

  public static void main(String[] args)
  {
    exitOnDestroyAll = true;
    if (args.length == 0)
      (new Jide()).show();
    else
      for (int i = 0; i < args.length; i++)
        (new Jide(new File(args[i]),false,false)).show();
  }
}
