package extensions.awt;
import java.awt.*;

/**
  * Create a Panel that can only strink so far.
  * Can be used for margin alignments.
  * @see java.awt.Panel
  * @version 1.0.2
  * @author John Webster Small
  */
public class MinimumPanel extends Panel
{
  private int width, height;

  /** Panel will not strink below minimums specified. */
  public void setMinimums(int width, int height)
  {
    this.width = width;
    this.height = height;
  }

  /** Panel will not strink below minimums specified. */
  public MinimumPanel(int width, int height)
  {
    this.width = width;
    this.height = height;
  }

  /** Called by layout manager. */
  public Dimension preferredSize()
  {
    Dimension d = super.preferredSize();
    if (d.width < width)
        d.width = width;
    if (d.height < height)
        d.height = height;
    return d;
  }

  /** Called by layout manager. */
  public Dimension minimumSize()
  {
    Dimension d = super.minimumSize();
    if (d.width < width)
        d.width = width;
    if (d.height < height)
        d.height = height;
    return d;
  }
}
