package extensions.awt;
import java.awt.*;

/** An OutlinedPanel is one with a wire border and
  * optional title.
  * @version 1.0.2
  * @author John Webster Small
  */ 
public class OutlinedPanel extends Panel
{
  private String title;
  private int height, descent, titleWidth;
  private int top, left, vmargin, hmargin;
  private static final int titleHmargins = 3;

  /** Title inset from left. */
  public static int titleLeftOffset = 20;

  private void metrics()
  {
    FontMetrics fm = this.getFontMetrics(this.getFont());
    height = fm.getHeight();
    descent = fm.getMaxDescent();
    if (title == null)
      titleWidth = 0;
    else
      titleWidth = fm.stringWidth(title);
    top = height/3*2;
    Insets i = super.insets();
    left = i.left;
    vmargin = top+i.bottom+1;
    hmargin = i.left+i.right+1;
  }

  /** @see java.awt.Component#addNotify */
  public void addNotify()
  {
    super.addNotify();
    metrics();
  }

  /** @see java.awt.Container#insets */
  public Insets insets()
  {
    Insets i = super.insets();
    i.top += height;
    i.top += descent;
    i.left++;
    i.right++;
    i.bottom++;
    return i;
  }

  /** @see java.awt.Component#preferredSize */
  public Dimension preferredSize()
  {
    Dimension d = super.preferredSize();
    int minWidth = (titleLeftOffset + titleHmargins) * 2 + titleWidth;
    if (d.width < minWidth)
      d.width = minWidth;
    return d;
  }

  /** Construct a Panel with a visible rectangle
    * outlining its extent.
    */
  public OutlinedPanel()
    { title = null; }

  /** Construct a Panel with a visible rectangle
    * outlining its extent.
    * @param title the title of this "group" panel
    */
  public OutlinedPanel(String title)
    { this.title = title; }

  /** @see java.awt.Component#paint */
  public void paint(Graphics g)
  {
    super.paint(g);
    Dimension d = size();
    g.drawRect(left,top,d.width-hmargin,d.height-vmargin);
    if (title != null)  {
      g.setColor(getBackground());
      g.drawLine(left+titleLeftOffset-titleHmargins,top,
        left+titleLeftOffset+titleWidth+titleHmargins,top);
      g.setColor(getForeground());
      g.drawString(title,titleLeftOffset,height);
    }
  }
}
