package extensions.lang;

/**
  * Counting Semaphore.
  * @see java.lang.Object#wait
  * @see java.lang.Object#notify
  * @version 1.0.2
  * @author John Webster Small
  */
public class Semaphore
{
  private int s;
  private int waiters;

  /** Initialize count.
    * @param count initial count */
  public Semaphore(int count)
  {
    if (count < 0)
      s = -count;
    else
      s = count;
    waiters = 0;
  }

  /**
    * Pass by semaphore if count can be decremented,
    * Otherwise wait to be signaled.
    */
  public synchronized void pass()
  {
    if (s >= 1)
      s--;
    else  {
      waiters++;
      try { wait(); }
      catch (InterruptedException ie) {}
      catch (IllegalMonitorStateException imse) {}
    }
  }

  /**
    * Notify any thread waiting otherwise increment
    * count.
    */
  public synchronized void signal()
  {
    if (waiters > 0)  {
      waiters--;
      try { notify(); }
      catch (IllegalMonitorStateException imse) {}
    }
    else
      s++;
  }
}
