package extensions.lang;
import java.util.*;
import extensions.awt.*;


class SystemPropertiesViewAdapter extends Action
{ public void run()  { SystemProperties.view(); } }

/** Provides handy access to System properties
  * typically used for bug workarounds.  Add to
  * properties broken out as required. All fields
  * are read only but left unprotected for efficiency
  * reasons!
  * @version 1.0.2
  * @author John Webster Small
  */
public class SystemProperties
{
  public static int jvm_major = 0;
  public static String jvm_minor = "";
  public static String jvm_subminor = "";

  public final static int Win95 = 1;
  public final static int WinNT = 2;
  public final static int OtherOS = 0;

  public static int os = OtherOS;
  public static int os_major = 0;
  public static String os_minor = "";
  public static String os_subminor = "";

  static {
    String s = System.getProperty("java.version");
    StringTokenizer t = new StringTokenizer(s,".");
    if (t.hasMoreTokens())
      jvm_major = Integer.parseInt(t.nextToken());
    if (t.hasMoreTokens())
      jvm_minor = t.nextToken();
    if (t.hasMoreTokens())
      jvm_subminor = t.nextToken();
    s = System.getProperty("os.name");
    if (s.indexOf("Windows") >= 0)
      if (s.indexOf("95") >= 0)
        os = Win95;
      else if (s.indexOf("NT") >= 0)
        os = WinNT;
    t = new StringTokenizer(System.getProperty("os.version"),".");
    if (t.hasMoreTokens())
      os_major = Integer.parseInt(t.nextToken());
    if (t.hasMoreTokens())
      os_minor = t.nextToken();
    if (t.hasMoreTokens())
      os_subminor = t.nextToken();
  }

  /** Return a TextFrame suitable for showing
    * system properties.
    */
  public static TextFrame view()
  {
    Properties p = System.getProperties();
    Enumeration e = p.propertyNames();
    String n;
    StringBuffer s = new StringBuffer();
    while (e.hasMoreElements())  {
     n = (String) e.nextElement();
     s.append(n+": "+p.getProperty(n)+"\n");
    }
    return new TextFrame("System Properties",new String(s),18,70);
  }

  /** @return a ActionProtocol adapter that launchs
    *   a SystemProperties view frame.
    * @see extensions.awt.ActionProtocol
    */
  public static ActionProtocol viewAdapter()
    { return new SystemPropertiesViewAdapter(); }

  /** View system properties. */
  public static void main(String[] args)
  {
    TextFrame f = view();
    f.exitOnDestroy = true;
    f.show();
  }
}
