package extensions.util;
import java.util.*;

/**
  * Convertion routines between arrays,
  * vectors, and enumerations.
  * @version 1.0.2
  * @author John Webster Small
  */
public class AVEC
{

  /** Convert an Enumeration to a Vector.
    * @param e enumeration to be converted
    * @param offset start element
    * @param count number of elements
    * @return Vector of elements from enumeration
    */
  public static Vector toVector
    (Enumeration e, int offset, int count)
  {
    if (offset < 0 || count <= 0)
      return null;
    while (offset-- > 0)
      if (e.hasMoreElements())
        e.nextElement();
      else
        return null;
    Vector v = new Vector();
    while (e.hasMoreElements() && count-- > 0)
      v.addElement(e.nextElement());
    if (v.size() == 0)
      return null;
    return v;
  }

  /** Convert an Enumeration to a Vector.
    * @param e enumeration to be converted
    * @return Vector of elements from enumeration
    */
  public static Vector toVector(Enumeration e)
    { return toVector(e,0,Integer.MAX_VALUE); }

  /** Convert a Vector into an Object[] array.
    * @param v Vector to be converted
    * @param offset start element
    * @param count number of elements
    * @return Object[] of elements from Vector
    */
  public static Object[] toArray
    (Vector v, int offset, int count)
  {
    if (offset < 0 || offset >= v.size() || count <= 0)
      return null;
    if ((offset + count > v.size())
      || (offset + count < offset))  // wrap to negative test
      count = v.size() - offset;
    Object[] array = new Object[count];
    for (int i = 0; count-- > 0; i++, offset++)
      array[i] = v.elementAt(offset);
    return array;
  }

  /** Convert a Vector into an Object[] array.
    * @param v Vector to be converted
    * @return Object[] of elements from Vector
    */
  public static Object[] toArray(Vector v)
    { return toArray(v,0,Integer.MAX_VALUE); }

  /** Convert an Enumeration into an Object[] array.
    * @param e enumeration to be converted
    * @param offset start element
    * @param count number of elements
    * @return Object[] of elements from Vector
    */
  public static Object[] toArray
    (Enumeration e, int offset, int count)
    { return toArray(toVector(e,offset,count)); }
  
  /** Convert an Enumeration into an Object[] array.
    * @param e enumeration to be converted
    * @param offset start element
    * @param count number of elements
    * @return Object[] of elements from Vector
    */
  public static Object[] toArray(Enumeration e)
    { return toArray(e,0,Integer.MAX_VALUE); }

  /** Convert an Object[] array into a Vector.
    * @param array array of elements to be converted
    * @param offset start element
    * @param count number of elements
    * @return Vector of elements from Object[] array
    */
  public static Vector toVector
    (Object[] array, int offset, int count)
  {
    int size = array.length;
    if (offset < 0 || offset >= size || count <= 0)
      return null;
    if ((offset + count > size)
      || (offset + count < offset))  // wrap to negative test
      count = size - offset;
    Vector v = new Vector(count);
    while (count-- > 0)
      v.addElement(array[offset++]);
    return v;
  }

  /** Convert an Object[] array into a Vector.
    * @param array array of elements to be converted
    * @return Vector of elements from Object[] array
    */
  public static Vector toVector(Object[] array)
    { return toVector(array,0,Integer.MAX_VALUE); }
}
