package extensions.util;
import java.util.*;

/**
  * Smalltalk styled collect enumeration.
  * @version 1.0.2
  * @author John Webster Small
  */
public abstract class Collect implements Enumeration
{
  private int idx;
  private Vector v;
  private Enumeration inputs;

  /** Override to define collect block.
    * @return returns object produced from input
    */
  protected abstract Object output(Object input);

  /** Call from your overridden constructor. */
  protected void init()
  {
    while (inputs.hasMoreElements())
      v.addElement(output(inputs.nextElement()));
    v.trimToSize();
  }

  /** Build enumeration from inputs.
    * @see #output
    * @param inputs raw material for building outputs
    */
  public Collect(Enumeration inputs)
  {
    idx = 0;
    v = new Vector();
    this.inputs = inputs;
  }

  /**
    * @return true if this enumeration
    * contains more elements; false otherwise.
    */
  public final boolean hasMoreElements()
    { return idx < v.size(); }

  /**
    * @return the next element of this enumeration
    * @exception NoSuchElementException if no more elements exist
    */
  public final Object nextElement()
    {
      try {
        return v.elementAt(idx++);
      } catch (Exception e)  {
        throw new NoSuchElementException
          ("Select");
      }
    }
}
